@@ -1,12 +1,16 @@
 ( cd bin ; rm -rf awk )
 ( cd bin ; ln -sf gawk awk )
 ( cd bin ; rm -rf gawk )
-( cd bin ; ln -sf gawk-3.1.1 gawk )
+( cd bin ; ln -sf gawk-3.1.3 gawk )
 ( cd usr/bin ; rm -rf awk )
 ( cd usr/bin ; ln -sf ../../bin/awk awk )
 ( cd usr/bin ; rm -rf gawk )
 ( cd usr/bin ; ln -sf ../../bin/gawk gawk )
 ( cd usr/bin ; rm -rf pgawk )
-( cd usr/bin ; ln -sf pgawk-3.1.1 pgawk )
+( cd usr/bin ; ln -sf pgawk-3.1.3 pgawk )
+( cd usr/bin ; rm -rf gawk-3.1.3 )
+( cd usr/bin ; ln -sf ../../bin/gawk-3.1.3 gawk-3.1.3 )
 ( cd usr/man/man1 ; rm -rf awk.1.gz )
 ( cd usr/man/man1 ; ln -sf gawk.1.gz awk.1.gz )
+( cd usr/man/man1 ; rm -rf pgawk.1.gz )
+( cd usr/man/man1 ; ln -sf gawk.1.gz pgawk.1.gz )
